Window

Struct Window 

pub struct Window {
    pub pos: UiValue<Vec2>,
    pub anchor: Anchor,
    pub size: UiValue<Vec2>,
}
Window - Declarative layout type that is defined by its size and position. Nodes with this layout are not included in the ui flow.

๐Ÿ› ๏ธ Example

let layout: UiLayout = Window::new().pos(Ab(100.0)).size(Rl(50.0)).pack();

Fields

pos: UiValue<Vec2>

Position of the node.

anchor: Anchor

Decides where position should be applied at.

size: UiValue<Vec2>

Size of the node layout.

Implementations

Source

impl Window

pub const fn new() -> Self

Creates new empty Window node layout.

pub fn full() -> Self

Creates new full Window node layout.

pub fn pos(self, pos: impl Into<UiValue<Vec2>>) -> Self

Replaces the position with a new value.

pub fn x(self, x: impl Into<UiValue<f32>>) -> Self

Replaces the x position with a new value.

pub fn y(self, y: impl Into<UiValue<f32>>) -> Self

Replaces the y position with a new value.

pub fn size(self, size: impl Into<UiValue<Vec2>>) -> Self

Replaces the size with a new value.

pub fn width(self, width: impl Into<UiValue<f32>>) -> Self

Replaces the width with a new value.

pub fn height(self, height: impl Into<UiValue<f32>>) -> Self

Replaces the height with a new value.

pub fn anchor(self, anchor: impl Into<Anchor>) -> Self

Replaces the anchor with a new value.

pub fn set_pos(&mut self, pos: impl Into<UiValue<Vec2>>)

Sets the position to a new value.

pub fn set_x(&mut self, x: impl Into<UiValue<f32>>)

Sets the x position to a new value.

pub fn set_y(&mut self, y: impl Into<UiValue<f32>>)

Sets the y position to a new value.

pub fn set_size(&mut self, size: impl Into<UiValue<Vec2>>)

Sets the size to a new value.

pub fn set_width(&mut self, width: impl Into<UiValue<f32>>)

Sets the width to a new value.

pub fn set_height(&mut self, height: impl Into<UiValue<f32>>)

Sets the height to a new value.

pub fn set_anchor(&mut self, anchor: impl Into<Anchor>)

Sets the anchor to a new value.

pub fn package(self) -> Layout

Packs the struct into Layout.