NodeTree

Struct NodeTree 

pub struct NodeTree<D, T> {
    pub data: Option<D>,
    pub node: Node<T>,
}
A hashmap-like data structure for organizing general data into recursive subnodes. Data is indexed and traversed using paths. It retains the order of insertion.

๐Ÿ“ Structure

All data is stored inside inner tree-like hierarchy. Each node can store users data and multiple subnodes.

> NodeTree
 |-> Node_1
 |    |-> Node_2
 |    |-> Node_3
 |    |    |-> Node_4
 |-> Node_5
 |    |-> Node_6

โš™๏ธ Paths

Paths are strings that are passed to the methods to retrive and mutate data. For example "foo/bar/bar" is a valid path syntax. You need to construct paths always from the point of view of the struct we pass them to. For example on the previous hierarchy:

If you want to access Node_4, you use path "Node_1/Node_3/Node_4" on NodeTree struct. You can also use "Node_3/Node_4" on Node_1 struct to get the same result.

Whitespaces are allowed in paths, but are not encouraged. Putting a dot as first symbol like this ".name" will hide the node from the tree. Just "." will refer to the same node. ".." is not supported and is actually a valid name.

You can also not specify the name when creating a node. That means the name will be generated. The format is as follows ".||#:N" with N being the .len() of the nodes hashmap.

๐Ÿ“ฆ Types

  • Generic (D) - Master data schema struct defining what surface data can be stored in NodeTree for all nodes to share.
  • Generic (N) - Node data schema struct defining what node-specific data can be stored in Node

โš ๏ธ Warning

Please refrain from manually using ".||#:0", ".||#:1", ".||#:2", โ€ฆ as names or NodeGeneralTrait::add_node will return errors.

Fields

data: Option<D>

Top-level data

This top-level data is meant to be shared for every node. Example usage is storing theme and other surface data.

node: Node<T>

Node

The starting root node.