pub struct Window {
pub pos: UiValue<Vec2>,
pub anchor: Anchor,
pub size: UiValue<Vec2>,
}Expand description
Window - Declarative layout type that is defined by its size and position. Nodes with this layout are not included in the ui flow.
๐ ๏ธ Example
let layout: UiLayout = Window::new().pos(Ab(100.0)).size(Rl(50.0)).pack();Fields
pos: UiValue<Vec2>Position of the node.
anchor: AnchorDecides where position should be applied at.
size: UiValue<Vec2>Size of the node layout.
Implementations
Sourceimpl Window
impl Window
Sourcepub fn pos(self, pos: impl Into<UiValue<Vec2>>) -> Self
pub fn pos(self, pos: impl Into<UiValue<Vec2>>) -> Self
Replaces the position with a new value.
Sourcepub fn width(self, width: impl Into<UiValue<f32>>) -> Self
pub fn width(self, width: impl Into<UiValue<f32>>) -> Self
Replaces the width with a new value.
Sourcepub fn height(self, height: impl Into<UiValue<f32>>) -> Self
pub fn height(self, height: impl Into<UiValue<f32>>) -> Self
Replaces the height with a new value.
Sourcepub fn set_height(&mut self, height: impl Into<UiValue<f32>>)
pub fn set_height(&mut self, height: impl Into<UiValue<f32>>)
Sets the height to a new value.
Sourcepub fn set_anchor(&mut self, anchor: impl Into<Anchor>)
pub fn set_anchor(&mut self, anchor: impl Into<Anchor>)
Sets the anchor to a new value.